import { IComponentRender } from '@zeedhi/common';
import { TekLogin } from './login';

export function getChildren(login: TekLogin): IComponentRender[] {
	return [
		{
			name: 'formLogin',
			component: 'ZdForm',
			children: [
				{
					name: 'user',
					component: 'ZdTextInput',
					dense: false,
					label: 'LOGIN_USER',
					value: '',
					grid: {
						cols: 12,
					},
					validations: {
						required: {},
					},
					events: {
						keydown: login.loginKeyEnter.bind(login),
					},
				},
				{
					id: 'PASSWORD',
					name: 'password',
					component: 'ZdPassword',
					dense: false,
					label: 'LOGIN_PASSWORD',
					value: '',
					grid: {
						cols: 12,
					},
					validations: {
						required: {},
					},
					events: {
						keydown: login.loginKeyEnter.bind(login),
					},
				},
				{
					name: 'login',
					component: 'ZdButton',
					label: 'LOGIN_SIGN_IN',
					color: 'primary',
					width: '100%',
					grid: {
						cols: 12,
					},
					events: {
						click: login.loginClick.bind(login),
					},
				},
				{
					name: 'privacy',
					component: 'ZdText',
					text: 'LOGIN_PRIVACY',
					cssClass: 'zd-mt-3',
					tag: 'a',
					grid: {
						cols: 6,
					},
					events: {
						click: login.privacyClick.bind(login),
					},
				},
				{
					name: 'forget',
					component: 'ZdText',
					text: 'LOGIN_FORGET',
					cssClass: 'zd-mt-3 zd-text-right',
					tag: 'a',
					grid: {
						cols: 6,
					},
					events: {
						click: login.forgetClick.bind(login),
					},
				},
				{
					name: 'divider',
					component: 'ZdDivider',
					cssClass: 'zd-my-3',
					grid: {
						cols: 12,
					},
				},
				{
					name: 'keep-connected',
					component: 'ZdCheckbox',
					dense: true,
					falseValue: 'No',
					trueValue: 'Yes',
					label: 'LOGIN_KEEP_CONNECTED',
					grid: {
						cols: 6,
					},
					events: {
						change: login.changeKeepConnected.bind(login),
					},
				},
				{
					name: 'language-select',
					component: 'ZdSelect',
					dense: false,
					autocomplete: false,
					showLabel: false,
					showHelper: false,
					clearable: false,
					dataValue: 'SHORT_NAME',
					dataText: 'NAME',
					grid: {
						cols: 6,
					},
					datasource: {
						data: [
							{ NAME: 'Português (Brasil)', SHORT_NAME: 'pt_br' },
							{ NAME: 'English (USA)', SHORT_NAME: 'en_us' },
						],
					},
					events: {
						change: login.changeLanguage.bind(login),
					},
				},
			],
		},
		{
			name: 'formExpiredPassword',
			component: 'ZdForm',
			isVisible: false,
			children: [
				{
					name: 'expiredText',
					component: 'ZdText',
					text: 'LOGIN_UPDATE_PASSWORD',
					tag: 'h3',
				},
				{
					name: 'user',
					component: 'ZdTextInput',
					dense: false,
					label: 'LOGIN_USER',
					disabled: true,
					grid: {
						cols: 12,
					},
					validations: {
						required: {},
					},
				},
				{
					name: 'password',
					component: 'ZdPassword',
					dense: false,
					label: 'LOGIN_ACTUAL_PASSWORD',
					grid: {
						cols: 12,
					},
					validations: {
						required: {},
					},
					events: {
						keydown: login.loginKeyEnterExpiredPasswordConfirm.bind(login),
					},
				},
				{
					name: 'newPassword',
					component: 'ZdPassword',
					dense: false,
					label: 'LOGIN_NEW_PASSWORD',
					grid: {
						cols: 12,
					},
					validations: {
						required: {},
					},
					events: {
						keydown: login.loginKeyEnterExpiredPasswordConfirm.bind(login),
					},
				},
				{
					name: 'confirmPassword',
					component: 'ZdPassword',
					dense: false,
					label: 'LOGIN_CONFIRM_NEW_PASSWORD',
					grid: {
						cols: 12,
					},
					validations: {
						required: {},
					},
					events: {
						keydown: login.loginKeyEnterExpiredPasswordConfirm.bind(login),
					},
				},
				{
					name: 'cancelExpiredPassword',
					component: 'ZdButton',
					label: 'LOGIN_CANCEL',
					color: 'primary',
					outline: true,
					width: '100%',
					grid: {
						cols: 6,
					},
					events: {
						click: login.loginExpiredPasswordCancel.bind(login),
					},
				},
				{
					name: 'confirmExpiredPassword',
					component: 'ZdButton',
					label: 'LOGIN_CONFIRM',
					color: 'primary',
					width: '100%',
					grid: {
						cols: 6,
					},
					events: {
						click: login.loginExpiredPasswordConfirm.bind(login),
					},
				},
			],
		},
		{
			name: 'formForgetPassword',
			component: 'ZdForm',
			isVisible: false,
			children: [
				{
					name: 'forgetText',
					component: 'ZdText',
					text: 'LOGIN_FORGET_PASSWORD',
					tag: 'h3',
				},
				{
					name: 'email',
					component: 'ZdTextInput',
					dense: false,
					label: 'LOGIN_EMAIL',
					grid: {
						cols: 12,
					},
					validations: {
						required: {},
					},
					events: {
						keydown: login.loginKeyEnterForgetPasswordConfirm.bind(login),
					},
				},
				{
					name: 'cancelForgetPassword',
					component: 'ZdButton',
					label: 'LOGIN_CANCEL',
					color: 'primary',
					outline: true,
					width: '100%',
					grid: {
						cols: 6,
					},
					events: {
						click: login.loginForgetPasswordCancel.bind(login),
					},
				},
				{
					name: 'confirmForgetPassword',
					component: 'ZdButton',
					label: 'LOGIN_CONFIRM',
					color: 'primary',
					width: '100%',
					grid: {
						cols: 6,
					},
					events: {
						click: login.loginForgetPasswordConfirm.bind(login),
					},
				},
			],
		},
		{
			name: 'formEmailPrivacyPolicy',
			component: 'ZdForm',
			isVisible: false,
			children: [
				{
					name: 'emailPrivacyText',
					component: 'ZdText',
					text: 'LOGIN_EMAIL_PRIVACY_POLICY',
					tag: 'h3',
				},
				{
					name: 'email',
					component: 'ZdTextInput',
					dense: false,
					label: 'LOGIN_EMAIL',
					grid: {
						cols: 12,
					},
					validations: {
						required: {},
					},
					events: {
						keydown: login.loginKeyEnterEmailPrivacyPolicyConfirm.bind(login),
					},
				},
				{
					name: 'cancelEmailPrivacyPolicy',
					component: 'ZdButton',
					label: 'LOGIN_CANCEL',
					color: 'primary',
					outline: true,
					width: '100%',
					grid: {
						cols: 6,
					},
					events: {
						click: login.loginEmailPrivacyPolicyCancel.bind(login),
					},
				},
				{
					name: 'confirmEmailPrivacyPolicy',
					component: 'ZdButton',
					label: 'LOGIN_CONFIRM',
					color: 'primary',
					width: '100%',
					grid: {
						cols: 6,
					},
					events: {
						click: login.loginEmailPrivacyPolicyConfirm.bind(login),
					},
				},
			],
		},
	];
}
